pub enum FormaFieldType {
Named(String),
Array {
array: Box<FormaFieldType>,
},
Shape {
shape: Vec<FormaField>,
},
}Expand description
How a forma field type is described in a runtime forma definition. Strings correspond to primitive names or entity names (for references).
Variants
Named(String)
“string” | “number” | “boolean” | “file” | “
Array
Fields

array: Box<FormaFieldType>Shape
Fields

shape: Vec<FormaField>Trait Implementations
Sourceimpl Clone for FormaFieldType
impl Clone for FormaFieldType
Sourcefn clone(&self) -> FormaFieldType
fn clone(&self) -> FormaFieldType
Returns a duplicate of the value. Read more
1.0.0 (const: unstable) · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for FormaFieldType
impl Debug for FormaFieldType
Sourceimpl Default for FormaFieldType
impl Default for FormaFieldType
Sourcefn default() -> FormaFieldType
fn default() -> FormaFieldType
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for FormaFieldType
impl<'de> Deserialize<'de> for FormaFieldType
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<FormaFieldType, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<FormaFieldType, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl PartialEq for FormaFieldType
impl PartialEq for FormaFieldType
Sourcefn eq(&self, other: &FormaFieldType) -> bool
fn eq(&self, other: &FormaFieldType) -> bool
Tests for
self and other values to be equal, and is used by ==.Sourceimpl Serialize for FormaFieldType
impl Serialize for FormaFieldType
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more
impl StructuralPartialEq for FormaFieldType